Learn R Programming

capn (version 2.0.0)

AFY: Abbott--Fenichel--Yun Data (1-D Stochastic Example)

Description

AFY contains approximation and simulation data used to replicate the one-dimensional stochastic example in Abbott, Fenichel, and Yun (2026), which extends the classic renewable resource model of Pindyck (1984). The dataset illustrates the natural capital asset pricing (CAPN) framework under uncertainty.

Usage

data("AFY")

Arguments

Format

A data.frame containing simulation and approximation data for a one-dimensional stochastic renewable resource model:

simData

A data.frame with the following components:

  • stock: Stock levels.

  • mu.d: Deterministic stock growth rate.

  • profit.d: Deterministic profit.

  • mu.s: Drift term of the stochastic stock process.

  • profit.s: Profit under stochastic dynamics.

  • sigs: Variance term of the stochastic process.

param

A data.frame of model and approximation parameters:

  • r: Intrinsic growth rate (=0.5)

  • K: Carrying capacity (=100)

  • b: Demand parameter (=1)

  • eta: elasticity of demand (=1/2)

  • c: cost parameter (=5)

  • gamma: elasticity of marginal cost (=2)

  • delta: discount rate (=0.05)

  • order: Chebyshev polynomial order (=30)

  • upperK: Upper bound of Chebyshev nodes (= 114.3)

  • lowerK: Lower bound of Chebyshev nodes (= 20)

  • nodes: Number of Chebyshev nodes (= 30)

Details

Following Abbott, Fenichel, and Yun (2026) and Pindyck (1984), the model is defined as follows.

Demand function: $$q(p) = b p^{-\eta}$$

Cost function: $$c(s) = c s^{-\gamma}$$

Biological growth function: $$f(s) = r s \left(1 - \frac{s}{K}\right)$$

Stock dynamics: $$ ds = \left[f(s) - q(s)\right] dt + \sigma s \, dz $$

Net benefit function: $$ \int_0^{q} p(z) \, dz - c(s) q(s) = -\frac{b^2}{q} - \frac{c}{s^2} q $$

Closed-form value function: $$ V(s) = -\frac{\phi}{s} - \frac{\phi r}{\delta K} $$

where $$ \phi = \frac{ 2 b^2 + 2 b \sqrt{b^2 + c (r + \delta - \sigma^2)} }{ (r + \delta - \sigma^2)^2 } $$

Optimal harvest (catch) function: $$ q(s) = b (\phi + c)^{-1/2} s $$

Parameter values:

  • \(r = 0.5\)

  • \(K = 1\) (=100% in the percentage replication)

  • \(b = 1\)

  • \(\eta = 0.5\)

  • \(c = 5\)

  • \(\gamma = 2\)

  • \(\delta = 0.05\)

References

Abbott, Joshua K., Eli P. Fenichel, and Seong D. Yun. (2026). Risky (Natural) Assets: Stochasticity, Nonconvexity, and the Value of Natural Capital. Journal of the Association of Environmental and Resource Economists, 13(5), 1269-1309. tools:::Rd_expr_doi("10.1086/741689")

Pindyck, Robert S. (1984). Uncertainty in the Theory of Renewable Resource Markets. Review of Economic Studies, 51(2), 289--303. tools:::Rd_expr_doi("10.2307/2297693")

See Also

vaprox, vaprox.pindyck, vsim