Learn R Programming

capn (version 2.0.0)

LV: Prey--Predator (Lotka--Volterra) Example Data (2-D Deterministic)

Description

LV contains simulated data for a prey--predator (Lotka--Volterra) bioeconomic model used to illustrate multi-dimensional natural capital asset pricing (CAPN) methods. This example corresponds to a two-dimensional deterministic setting. The dataset includes both approximation data on a Chebyshev grid and time-series simulation output from the underlying dynamic system. See vignette("LVDemo") for an example demonstrating the use of this data.

Usage

data("LV")

Arguments

Format

A list with two elements:

lvaproxdata

A data.frame of approximation data evaluated on a \(20 \times 20\) Chebyshev grid:

  • xs: Prey stock

  • ys: Predator stock

  • xdot: Evaluated prey dynamics \(\frac{dx}{dt}\)

  • ydot: Evaluated predator dynamics \(\frac{dy}{dt}\)

  • wval: Profit (objective value \(W\) in Fenichel and Abbott (2014))

lvsimdata

A data.frame of time-series simulation output from solving the ODE system:

  • tseq: Time sequence from 0 to 100

  • xs: Prey stock

  • ys: Predator stock

Details

The prey--predator system is given by:

Prey (\(X\)): \( \dot{X} = r X \left( 1 - \frac{X}{K} \right) - a X Y - \theta X \)

Predator (\(Y\)): \( \dot{Y} = b X Y - m Y - \gamma Y \)

The biological parameters are:

  • \(r = 0.025\): Intrinsic growth rate of prey

  • \(K = 1\): Carrying capacity of prey

  • \(a = 0.08\): Predation effect on prey

  • \(b = 0.05\): Prey-to-predator conversion parameter

  • \(m = 0.01\): Natural mortality rate of predator

  • \(\gamma = 0.005\): Predator harvest control slope

  • \(\theta = 0.005\): Prey harvest control slope

The economic objective is defined as: \( W = \text{harv.prey} \, (p_{\text{prey}} - c_{\text{prey}} / X) \, \theta X + \text{harv.pred} \, (p_{\text{pred}} - c_{\text{pred}} / Y) \, \gamma Y \)

The economic parameters are:

  • \(p_{\text{pred}} = 0\): Price per unit harvest of predator

  • \(p_{\text{prey}} = 25\): Price per unit harvest of prey

  • \(c_{\text{prey}} = 0.1 \, p_{\text{prey}}\): Cost per unit of prey effort (Schaefer model, with \(q = 1\))

  • \(c_{\text{pred}} = c_{\text{prey}}\): Cost per unit of predator effort (Schaefer model, with \(q = 1\))