Learn R Programming

capn (version 2.0.0)

aproxdef: Define Approximation Space

Description

Define an approximation space for the value function and price function approximation methods (V, P, and Pdot).

Usage

aproxdef(deg, lb, ub, delta)

Value

A list defining the approximation space, containing polynomial degrees, bounds, and discount rate.

Arguments

deg

A vector specifying the number of polynomials (degrees of Chebyshev polynomials) in each dimension.

lb

A vector of lower bounds for each dimension.

ub

A vector of upper bounds for each dimension.

delta

A numeric scalar specifying the discount rate.

Details

For the \(i\)-th dimension, \(i = 1, 2, \ldots, d\), suppose a polynomial approximant over a bounded interval \([a_{i}, b_{i}]\) is defined using Chebyshev polynomials. Then, a \(d\)-dimensional approximation domain is defined as:

\(\mathbf{S} = \left\{ (s_{1}, s_{2}, \ldots, s_{d}) \mid a_{i} \leq s_{i} \leq b_{i}, \; i = 1, 2, \ldots, d \right\}. \)

Suppose \(n_{i}\) Chebyshev polynomials (i.e., degree \(n_{i}-1\)) are used for the \(i\)-th dimension. The approximation space is defined by:

deg = c(\(n_{1}, n_{2}, \ldots, n_{d}\)),
lb = c(\(a_{1}, a_{2}, \ldots, a_{d}\)), and
ub = c(\(b_{1}, b_{2}, \ldots, b_{d}\)).

The argument delta is the constant discount rate used in the approximation.

References

Fenichel, Eli P. and Joshua K. Abbott. (2014). Natural Capital: From Metaphor to Measurement. Journal of the Association of Environmental Economists, 1(1/2), 1--27. tools:::Rd_expr_doi("10.1086/676034")

Examples

Run this code
## Reef-fish example: see Fenichel and Abbott (2014)
delta <- 0.02          # discount rate
upper <- 359016000     # upper bound on approximation space
lower <- 5e+6          # lower bound on approximation space

myspace <- aproxdef(50, lower, upper, delta)

## Two-dimensional example
ub <- c(1.5, 1.5)
lb <- c(0.1, 0.1)
deg <- c(20, 20)
delta <- 0.03

myspace <- aproxdef(deg, lb, ub, delta)

Run the code above in your browser using DataLab