Learn R Programming

capn (version 2.0.0)

pdotsim: Simulation of Pdot-Approximation

Description

Simulates shadow prices and value functions using coefficients from the Pdot-approximation obtained via pdotaprox.

Usage

pdotsim(pdotcoeff, stock, sdot, dsdotds, wval, dwds)

Value

A list of approximation results. Use results$item

(or results[["item"]]) to extract individual components:

shadowp

Estimated shadow (accounting) prices, \(\hat{p}(s)\).

iw

Inclusive wealth, \(\hat{p}(s)\, s\).

vfun

Estimated value function, \(\hat{V}(s)\).

stock

Stock values used in the simulation.

wval

\(W\)-values used in the simulation.

Arguments

pdotcoeff

An approximation result from the pdotaprox function.

stock

A numeric vector of stock values, \(s\).

sdot

A numeric vector of stock growth rates, \(\dot{s} = \frac{ds}{dt}\).

dsdotds

A numeric vector of derivatives of stock growth with respect to stock, \(\frac{d \dot{s}}{d s}\).

wval

A numeric vector of \(W\)-values.

dwds

A numeric vector of marginal \(W\)-values, \(\frac{dW}{ds}\).

Details

Let \(\hat{\beta}\) denote the vector of approximation coefficients from pdotaprox. Over the approximation interval \(s \in [a,b]\), the estimated shadow (accounting) price is given by:

\( \hat{p}(s) = \frac{ W_{s}(s) + \mathbf{\mu}(s)\hat{\beta} } { \delta - \dot{s}_{s}(s) } \).

The corresponding estimated value function is:

\( \hat{V}(s) = \frac{1}{\delta} \left( W(s) + \hat{p}(s)\, \dot{s}(s) \right) \).

These expressions follow directly from the Pdot-approximation framework developed in Fenichel and Abbott (2014) and Fenichel et al. (2016).

References

Fenichel, Eli P. and Joshua K. Abbott. (2014). Natural Capital: From Metaphor to Measurement. Journal of the Association of Environmental Economists, 1(1/2), 1--27. tools:::Rd_expr_doi("10.1086/676034")

Fenichel, Eli P., Joshua K. Abbott, Jude Bayham, Whitney Boone, Erin M. K. Haacker, and Lisa Pfeiffer. (2016) Measuring the Value of Groundwater and Other Forms of Natural Capital. Proceedings of the National Academy of Sciences. 113: 2382--2387. tools:::Rd_expr_doi("10.1073/pnas.1513779113")

See Also

aproxdef, pdotaprox, plotgen, GOM

Examples

Run this code
## 1-D Reef-fish example: see Fenichel and Abbott (2014)
data("GOM")

param <- GOM$param
simData <- GOM$simData

Aspace <- aproxdef(param$order, param$lowerK, param$upperK, param$delta)

pdotC <- pdotaprox(
  Aspace,
  simData$stock,
  simData$sdot,
  simData$dsdotds,
  simData$dsdotdss,
  simData$dwds,
  simData$dwdss
)

GOMSimPdot <- pdotsim(
  pdotC,
  simData$stock,
  simData$sdot,
  simData$dsdotds,
  simData$profit,
  simData$dwds
)

## Shadow price
plotgen(GOMSimPdot,
        xlabel = "Stock size, s",
        ylabel = "Shadow price")

## Value function and profit
plotgen(GOMSimPdot,
        ftype  = "vw",
        xlabel = "Stock size, s",
        ylabel = c("Value Function", "Profit"))

Run the code above in your browser using DataLab