Learn R Programming

capn (version 2.0.0)

psim: Simulation of P-Approximation

Description

Simulates the P-approximation by evaluating the estimated shadow price function and, optionally, the associated value function over a given set of stock values.

Usage

psim(pcoeff, stock, wval = NULL, sdot = NULL)

Value

A list containing simulated P-approximation outputs. Use result$item (or result[["item"]]) to extract individual components.

shadowp

Estimated shadow (accounting) prices, \(\hat{p}(s)\).

iw

Inclusive wealth, defined as \(\hat{p}(s) \cdot s\).

vfun

Estimated value function, \(\hat{V}(s)\). Returned only if both wval and sdot are provided; otherwise NULL.

stock

Stock values used for evaluation, returned as a column matrix.

wval

Flow payoff values, \(W(s)\), if provided; otherwise NULL.

Arguments

pcoeff

An approximation result object returned by paprox.

stock

A numeric vector of stock values at which to evaluate the P-approximation.

wval

(Optional) A numeric vector of flow payoff values, \(W(s)\). Must be provided together with sdot in order to compute the value function.

sdot

(Optional) A numeric vector of stock dynamics, \(\dot{s} = \frac{ds}{dt}\). Must be provided together with wval in order to compute the value function.

Details

Let \(\hat{\beta}\) denote the vector of approximation coefficients returned by paprox. The estimated shadow (accounting) price over the approximation interval \(s \in [a,b]\) is given by:

\(\hat{p}(s) = \boldsymbol{\Phi}(s) \, \hat{\boldsymbol{\beta}},\)

where \(\boldsymbol{\Phi}(s)\) denotes the vector of Chebyshev basis functions.

If both wval and sdot are provided, the estimated value function is computed as:

\( \hat{V}(s) = \frac{1}{\delta} \left( W(s) + \hat{p}(s) \, \dot{s}(s) \right). \)

For additional theoretical details, see Fenichel and Abbott (2014) and Fenichel et al. (2016).

References

Fenichel, Eli P. and Joshua K. Abbott. (2014). Natural Capital: From Metaphor to Measurement. Journal of the Association of Environmental Economists, 1(1/2), 1--27. tools:::Rd_expr_doi("10.1086/676034")

Fenichel, Eli P., Joshua K. Abbott, Jude Bayham, Whitney Boone, Erin M. K. Haacker, and Lisa Pfeiffer. (2016) Measuring the Value of Groundwater and Other Forms of Natural Capital. Proceedings of the National Academy of Sciences. 113: 2382--2387. tools:::Rd_expr_doi("10.1073/pnas.1513779113")

See Also

aproxdef, paprox, plotgen, GOM

Examples

Run this code
## 1-D Reef-fish example: see Fenichel and Abbott (2014)
data("GOM")

param <- GOM$param
simData <- GOM$simData

Aspace <- aproxdef(param$order, param$lowerK, param$upperK, param$delta)

pC <- paprox(
  Aspace,
  simData$stock,
  simData$sdot,
  simData$dsdotds,
  simData$dwds
)

GOMSimP <- psim(
  pC,
  simData$stock,
  simData$profit,
  simData$sdot
)

## Shadow price
plotgen(GOMSimP, xlabel = "Stock size, s", ylabel = "Shadow price")

## Value function and profit
plotgen(
  GOMSimP,
  ftype  = "vw",
  xlabel = "Stock size, s",
  ylabel = c("Value Function", "Profit")
)

Run the code above in your browser using DataLab