GOM contains parameters and simulated data used to replicate the
Gulf of Mexico reef fish example from Fenichel and Abbott (2014).
The dataset illustrates the natural capital asset pricing (CAPN)
framework in a one-dimensional deterministic setting.
data("GOM")A list with two elements:
A data.frame of model and approximation parameters:
r: Intrinsic growth rate (= 0.3847)
k: Carrying capacity (= 359016000)
q: Catchability coefficient (= 0.00031729344157311126)
price: Output price (= 2.70)
cost: Unit cost (= 153.0)
alpha: Technology parameter (= 0.5436459179063678)
gamma: Pre-ITQ management parameter (= 0.7882)
y: System equivalence parameter (= 0.15745573410462155)
delta: Discount rate (= 0.02)
order: Chebyshev polynomial order (= 50)
upperK: Upper bound of Chebyshev nodes (= k)
lowerK: Lower bound of Chebyshev nodes (= \(5 \times 10^{6}\))
nodes: Number of Chebyshev nodes (= 50)
A data.frame of simulated values evaluated at approximation nodes:
stock: Approximation nodes
profit: Profit evaluated at stock
sdot: Evaluated stock dynamics \(\frac{ds}{dt}\)
dsdotds: Evaluated \(\frac{d}{ds}\left( \frac{ds}{dt} \right)\)
dsdotdss: Evaluated \(\frac{d^2}{ds^2}\left( \frac{ds}{dt} \right)\)
dwds: Evaluated \(\frac{dw}{ds}\)
dwdss: Evaluated \(\frac{d^2 w}{ds^2}\)
From Fenichel and Abboott(2014),
catch effort: \(x(s)=ys^\gamma\),
harvest: \(h(s,x)=q((ys^\gamma)^\alpha)s=q(y^\alpha)(s^{\gamma\alpha})\),
profit: \(w(s,x)=price \cdot h(s,x) - cost \cdot x(s)\), and
sdot: \(\dot{s} = rs \left( 1 - \frac{s}{k} \right) - q(y^\alpha)(s^{\gamma \alpha + 1})\).
The biological parameters are:
\(r = 0.3847\): Intrinsic growth rate
\(K = 359016000\): Carrying capacity
The economic parameters are:
\(q = 0.00031729344157311126\): Catchability coefficient
\(price = 2.70\): Output price
\(cost = 153.0\): Unit cost
\(alpha = 0.5436459179063678\): Technology parameter
\(gamma = 0.7882\): Pre-ITQ management parameter
\(y = 0.15745573410462155\): System equivalence parameter
\(delta = 0.02\): Discount rate
Fenichel, Eli P. and Joshua K. Abbott. (2014). Natural Capital: From Metaphor to Measurement. Journal of the Association of Environmental Economists, 1(1/2), 1--27. tools:::Rd_expr_doi("10.1086/676034")