forest contains parameters and simulated data used to replicate the
Douglas-fir forest in Western Oregon example (industrial siteclass 3) from Hashida and Fenichel (2022).
The dataset illustrates the natural capital asset pricing (CAPN)
framework in a one-dimensional deterministic setting.
See vignette("forestDemo") for an example demonstrating the use of this data.
data("forest")A list with two elements:
A data.frame of model and approximation parameters:
delta: Discount rate (= 0.07)
order: Chebyshev polynomial order (= 400)
lowerK: lower bound of Chebyshev nodes (= 1)
upperK: Upper bound of Chebyshev nodes (= 80)
nodes: Number of Chebyshev nodes (= 400)
crit.vol: Boundary (Moratorium or Maximum Standing) Volume (= 18.6592)
margp: Marginal use value \(\frac{d \pi}{d s}\) at crit.vol (= 743.439)
splittime: Split time \(t(s)\) at crit.vol (= 57.21486)
A data.frame of simulated values evaluated at approximation nodes:
vol: Forest volume (MBF) at Chevyshev nodes in \(s \in \) [1,80]
growth: Evaluated stock dynamics \(\frac{ds}{dt}\) at vol
profit: Profit evaluated at vol
times: Evaluated time with \(t(s)\) at vol
See Hashida and Fenichel (2022).
Hashida, Yukiko and Eli P. Fenichel. (2022). Valuing Natural Capital When Management Is Dominated by Periods of Inaction. American Journal of Agricultural Economics, 104(2), 791--811. tools:::Rd_expr_doi("10.1111/ajae.12250")